@@ -596,30 +596,41 @@ ev_document_misc_get_widget_dpi (GtkWidget *widget)
 	}
 }
 
-/* Returns a locale specific date and time representation */
+/**
+ * ev_document_misc_format_date:
+ * @utime: a #GTime
+ *
+ * Returns: (transfer full): a locale specific date and time representation.
+ *
+ * Deprecated: 3.38: use ev_document_misc_format_datetime instead as GTime is
+ *                   deprecated because it is not year-2038 safe.
+ */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 gchar *
 ev_document_misc_format_date (GTime utime)
 {
-	time_t time = (time_t) utime;
-	char s[256];
-	const char fmt_hack[] = "%c";
-	size_t len;
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wformat-y2k"
-#ifdef HAVE_LOCALTIME_R
-	struct tm t;
-	if (time == 0 || !localtime_r (&time, &t)) return NULL;
-	len = strftime (s, sizeof (s), fmt_hack, &t);
-#else
-	struct tm *t;
-	if (time == 0 || !(t = localtime (&time)) ) return NULL;
-	len = strftime (s, sizeof (s), fmt_hack, t);
-#endif
-#pragma GCC diagnostic pop
+	g_autoptr (GDateTime) dt = g_date_time_new_from_unix_utc ((gint64)utime);
+	return ev_document_misc_format_datetime (dt);
+}
+G_GNUC_END_IGNORE_DEPRECATIONS
 
-	if (len == 0 || s[0] == '\0') return NULL;
-
-	return g_locale_to_utf8 (s, -1, NULL, NULL, NULL);
+/**
+ * ev_document_misc_format_datetime:
+ * @dt: a #GDateTime
+ *
+ * Determine the preferred date and time representation for the current locale
+ * for @dt.
+ *
+ * Returns: (transfer full): a new allocated string or NULL in the case
+ * that there was an error (such as a format specifier not being supported
+ * in the current locale). The string should be freed with g_free().
+ *
+ * Since: 3.38
+ */
+gchar *
+ev_document_misc_format_datetime (GDateTime *dt)
+{
+	return g_date_time_format (dt, "%c");
 }
 
 /**
